from pymemri.data.schema import Item, Edge

class Account(Item):
    
    def __init__(self, service, identifier=None, secret=None, code=None, id=None, deleted=None): #e.g. username, password or access key, secret key etc.
        self.id = id
        self.deleted = deleted
        self.service = service
        self.identifier = identifier
        self.secret = secret
        self.code = code
        
    @classmethod
    def from_json(cls, json):
        id = json.get("id", None)
        deleted = json.get("deleted", None)
        service = json.get("service", None)
        identifier = json.get("identifier", None)
        secret = json.get("secret", None)
        code = json.get("code", None)

        res = cls(service=service, identifier=identifier, secret=secret, code=code, id=id, deleted=deleted)
        return res


class Plugin(Item):
    
    def __init__(self, name, container, account=None, id=None, deleted=None):
        super().__init__(id=id, deleted=deleted)
        self.name = name
        self.container = container
        self.account = account if account else []

    @classmethod
    def from_json(cls, json):
        id = json.get("id", None)
        deleted = json.get("deleted", None)
        name = json.get("name", None)
        container = json.get("container", None)
        all_edges = json.get("allEdges", None)
        
        account = []
        
        if all_edges is not None:
            for edge_json in all_edges:
                edge = Edge.from_json(edge_json)
                if edge._type == "account" or edge._type == "~account": 
                    account.append(edge)
                
        res = cls(name=name, container=container, account=account, id=id, deleted=deleted)
        for e in res.get_all_edges(): e.source = res
        return res

class StartPlugin(Item):
    
    def __init__(self, targetItemId, container, state=None, oAuthUrl=None, view=None, id=None, deleted=None):
        super().__init__(id=id, deleted=deleted)
        self.targetItemId = targetItemId
        self.container = container
        self.state = state
        self.oAuthUrl = oAuthUrl
        # CVUStoredDefinitions
        self.view = view if view else None


    @classmethod
    def from_json(cls, json):
        id = json.get("id", None)
        deleted = json.get("deleted", None)
        targetItemId = json.get("targetItemId", None)
        container = json.get("container", None)
        state = json.get("state", None)
        oAuthUrl = json.get("oAuthUrl", None)
        all_edges = json.get("allEdges", None)

        view = []

        if all_edges is not None:
            for edge_json in all_edges:
                edge = Edge.from_json(edge_json)
                if edge._type == "view" or edge._type == "~view": 
                    view.append(edge)

        res = cls(targetItemId=targetItemId, container=container, state=state, view=view, oAuthUrl=oAuthUrl, id=id, deleted=deleted)
        return res