from plugin_template.plugin_flow.plugin_flow import PluginFlow
from plugin_template.service_api.service_api import ServiceAPI

SERVICE_NAME = 'demo-service'

class PluginTemplate(PluginFlow):

    def __init__(self, client, plugin=None, start_plugin_id=None, app_id=None, app_secret=None):
        print("PLUGIN run is initialized", self.__dict__)
        self.dummy_service = ServiceAPI()
        # activate plugin flow
        if plugin and start_plugin_id:
            super().__init__(client=client, plugin=plugin, run_id=start_plugin_id)
            # init login process
            # self.start_auth_oauth()
            self.start_auth_userpass_and_two_factor()

    def check_existing_auth(self):
        account = self.get_account_from_plugin(SERVICE_NAME)
        if account:
            result = self.dummy_service.login(account.identifier, account.secret)
            if result['success']:
                return True
        return False

    def start_auth_userpass_and_two_factor(self):
        #
        if self.check_existing_auth(): return True

        for _ in range(3):
            # we request username and password here
            account = self.ask_user_for_accounts(SERVICE_NAME, 'username-password-view')
            # check if they work
            result = self.dummy_service.login(account.identifier, account.secret)
            print("Checking login")
            if result and result['success'] == True:
                if result['2fa_required']:
                    for _ in range(3):
                        account = self.ask_user_for_accounts(SERVICE_NAME, '2fa-view')
                        result = self.dummy_service.complete_2fa(account.code)
                        print("Checking 2fa")
                        if result['success']:
                            print("Access granted")
                            return True
                else:
                    print("Access granted")
                    return True
        return False


    def start_auth_oauth(self):

        if self.check_existing_auth(): return True

        oauth_url = self.dummy_service.get_oauth_url(self.app_id, self.app_secret)
        for i in range(3):
            account = self.ask_user_for_accounts(SERVICE_NAME, 'oauth-view', oauth_url)
            result = self.dummy_service.get_oauth_token(account.code)
            print("Checking login")
            if result['success']:
                print("Access granted")
                self.set_account('oauth', result['token'], SERVICE_NAME) # or "username", "passord"
                return True
        return False
            

    def run(self):

        print('Running')
        self.started()

        if self.dummy_service.authenticated:
            print("Authtentication success")

            # Import stuff
            # items = self.dummy_service.getItems()
            # for item in items:
            #     self.client.create(item)
            print("API", self.dummy_service.__dict__)
            items = self.client.search({'type': 'Plugin'})
            for item in items:
                print("PLUGIN ITEM", item.__dict__)

        print("PLUGIN run is completed")
        self.completed()



    