from plugin_template import data
from plugin_template.plugin_template import PluginTemplate
from pymemri.pod.client import PodClient
from plugin_template.data.schema import Plugin # Remove this later, after moving json plugin parser into PluginFlow
from plugin_template.plugin_flow.plugin_flow import PluginFlow

import os, json    

def main(pod_url=None, database_key=None, owner_key=None, plugin_item=None, start_plugin_id=None, auth_json=None):
    # setup client
    client = PodClient(url=pod_url, database_key=database_key, owner_key=owner_key, auth_json=auth_json)

    # Get plugin item from the POD.
    # expand? we need credential edges. Also move into PluginFlow after getting plugin_id only.
    plugin = Plugin.from_json(json.loads(plugin_item))

    # ----- PLUGIN STARTS ------

    plugin = PluginTemplate(client, plugin, start_plugin_id)
    try:
        plugin.run()
    except Exception as e:
        plugin.failed(e)


    # ------ PLUGIN ENDS ------


def parse_environment_variables():
    plugin_data = {}
    env_variable_keys = {
        'auth_json': 'POD_AUTH_JSON',
        'owner_key': 'POD_OWNER',
        'plugin_item': 'POD_TARGET_ITEM',
        'pod_url': 'POD_FULL_ADDRESS',
        'start_plugin_id': 'POD_PLUGINRUN_ID'
    }
    # extract
    for k, v in env_variable_keys.items():
        if not v in os.environ:
            print(f"Missing environment variable: {v}. Exiting...")
            exit()
        plugin_data[k] = os.environ[v]
        # parse auth json
        if k == 'auth_json' and plugin_data[k]:
            plugin_data[k] = json.loads(plugin_data[k])
    return plugin_data



# EXTRACT PARAMETERS FROM ENVIRONMENT
if __name__ == "__main__":

    plugin_data = parse_environment_variables()

    main(**plugin_data)
