from pymemri.data.schema import Address, Event, Person
from pymemri.pod.client import PodClient
from datetime import datetime

def generate_test_data():

    items = []

    e1 = Event(itemDescription="New York Event", startTime=int(datetime.strptime("07/07/2022", "%d/%m/%Y").timestamp()))
    a1 = Address(city="New York", country="USA")
    e1.add_edge('location', a1)
    e2 = Event(itemDescription="Berlin Event", startTime=int(datetime.strptime("09/07/2022", "%d/%m/%Y").timestamp()))
    a2 = Address(city="Berlin", country="Germany")
    e2.add_edge('location', a2)
    items += [a1, a2, e1, e2]

    p = Person(firstName="", lastName="")
    a = Address(city="New York")
    p.add_edge('address', a)
    items += [a, p]

    p = Person(firstName="", lastName="")
    a = Address(city="Berlin")
    p.add_edge('address', a)
    items += [a, p]

    p = Person(firstName="", lastName="")
    a = Address(city="Bangkok")
    p.add_edge('address', a)
    items += [a, p]

    p = Person(firstName="", lastName="")
    a = Address(city="Tokyo")
    p.add_edge('address', a)
    items += [a, p]

    return items


def setup_test_database(client):

    ## set schemas
    client.add_to_schema(Event(itemDescription="", startTime=1))
    client.add_to_schema(Person(firstName="", lastName="", ))
    client.add_to_schema(Address(city="", country=""))

    existing = client.search({'type': 'Event'})
    if not existing or len(existing) == 0:
        print("Setting up database")
        
        items = generate_test_data()
        for item in items:
            client.create(item)

        for item in items:
            item.update(client, edges=True)
    else:
        print("Test database is already loaded")
    